GetAdjustmentSpecFileNames: GetAdjustmentSpecFileNames

View source: R/GetAdjustmentSpecFileNames.R

GetAdjustmentSpecFileNamesR Documentation

GetAdjustmentSpecFileNames

Description

Get the list of adjustment file names in a specific folder. By default the search folder is adjustments folder installed with package hivEstimatesAccuracy.

Usage

GetAdjustmentSpecFileNames(
  path = system.file("adjustments", package = "hivEstimatesAccuracy")
)

Arguments

path

Path to the folder with adjustment specifications. Optional. Default = system.file("adjustments", package = "hivEstimatesAccuracy").

Value

Character vector of adjustment specification file paths.

Examples

## Not run: 
GetAdjustmentSpecFileNames()

## End(Not run)


nextpagesoft/hivEstimatesAccuracy documentation built on Sept. 17, 2024, 5 a.m.